@@ -74,6 +74,11 @@
 #' returned as character.  If true, [readr::read_csv()] guesses the intended
 #' data type for each column.
 #' @param guess_max Deprecated.
+#' @param http_response_encoding  The encoding value passed to
+#' [httr::content()].  Defaults to 'UTF-8'.
+#' @param locale a [readr::locale()] object to specify preferences like
+#' number, date, and time formats.  This object is passed to
+#' [`readr::read_csv()`].  Defaults to [readr::default_locale()].
 #' @param verbose A boolean value indicating if `message`s should be printed
 #' to the R console during the operation.  The verbose output might contain
 #' sensitive information (*e.g.* PHI), so turn this off if the output might
@@ -190,6 +195,8 @@ redcap_read <- function(
   col_types                     = NULL,
   guess_type                    = TRUE,
   guess_max                     = NULL, # Deprecated parameter
+  http_response_encoding        = "UTF-8",
+  locale                        = readr::default_locale(),
   verbose                       = TRUE,
   config_options                = NULL,
   id_position                   = 1L
@@ -217,8 +224,11 @@ redcap_read <- function(
   checkmate::assert_posixct(  datetime_range_end        , any.missing=TRUE , len=1, null.ok=TRUE)
 
   checkmate::assert_logical(  guess_type                , any.missing=FALSE,     len=1)
-
   if (!is.null(guess_max)) warning("The `guess_max` parameter in `REDCapR::redcap_read()` is deprecated.")
+
+  checkmate::assert_character(http_response_encoding    , any.missing=FALSE,     len=1)
+  checkmate::assert_class(    locale, "locale"          , null.ok = FALSE)
+
   checkmate::assert_logical(  verbose                   , any.missing=FALSE,     len=1, null.ok=TRUE)
   checkmate::assert_list(     config_options            , any.missing=TRUE ,            null.ok=TRUE)
   checkmate::assert_integer(  id_position               , any.missing=FALSE,     len=1, lower=1L)
@@ -258,12 +268,14 @@ redcap_read <- function(
     token              = token,
     records_collapsed  = records_collapsed,
     fields_collapsed   = metadata$data$field_name[id_position],
-    forms_collapsed    = forms_collapsed,
+    # forms_collapsed    = forms_collapsed,
     events_collapsed   = events_collapsed,
     filter_logic       = filter_logic,
     datetime_range_begin   = datetime_range_begin,
     datetime_range_end     = datetime_range_end,
     guess_type         = guess_type,
+    http_response_encoding = http_response_encoding,
+    locale             = locale,
     verbose            = verbose,
     config_options     = config_options
   )
@@ -291,7 +303,7 @@ redcap_read <- function(
   # Continue as intended if the initial query succeeded. --------------------
   unique_ids <- sort(unique(initial_call$data[[id_position]]))
 
-  if (all(nchar(unique_ids)==32L))
+  if (0L < length(unique_ids) & all(nchar(unique_ids)==32L))
     warn_hash_record_id()  # nocov
 
   ds_glossary            <- REDCapR::create_batch_glossary(row_count=length(unique_ids), batch_size=batch_size)
@@ -313,6 +325,11 @@ redcap_read <- function(
         min(selected_ids), " through ", max(selected_ids),
         " (ie, ", length(selected_ids), " unique subject records)."
       )
+      # message(
+      #   "\nReading batch ", i, " of ", nrow(ds_glossary), ", with subjects ",
+      #   paste(selected_ids, collapse = ','),
+      #   "\n(ie, ", length(selected_ids), " unique subject records)."
+      # )
     }
     read_result <- REDCapR::redcap_read_oneshot(
       redcap_uri                  = redcap_uri,
@@ -334,6 +351,8 @@ redcap_read <- function(
       col_types                   = col_types,
       guess_type                  = FALSE,
       # guess_max                   = guess_max, # Not used, because guess_type is FALSE
+      http_response_encoding      = http_response_encoding,
+      locale                      = locale,
       verbose                     = verbose,
       config_options              = config_options
     )
@@ -372,7 +391,33 @@ redcap_read <- function(
   if (is.null(col_types) && guess_type) {
     ds_stacked <-
       ds_stacked %>%
-      readr::type_convert()
+      readr::type_convert(
+        locale = locale
+      )
+  }
+
+  unique_ids_actual <- sort(unique(ds_stacked[[id_position]]))
+  ids_missing_rows  <- setdiff(unique_ids, unique_ids_actual)
+
+  if (0L < length(ids_missing_rows)) {
+    message_template <-
+      paste0(
+        "There are %i subject(s) that are missing rows in the returned dataset. ",
+        "REDCap's PHP code is likely trying to process too much text in one bite.\n\n",
+        "Common solutions this problem are:\n",
+        "  - specifying only the records you need (w/ `records`)\n",
+        "  - specifying only the fields you need (w/ `fields`)\n",
+        "  - specifying only the forms you need (w/ `forms`)\n",
+        "  - specifying a subset w/ `filter_logic`\n",
+        "  - reduce `batch_size`\n\n",
+        "The missing ids are:\n",
+        "%s."
+      )
+    stop(sprintf(
+      message_template,
+      length(ids_missing_rows),
+      paste(ids_missing_rows, collapse=",")
+    ))
   }
 
   elapsed_seconds          <- as.numeric(difftime( Sys.time(), start_time, units="secs"))
